@@ -2,10 +2,10 @@
 #
 # Module  : IDspace.pm
 # Purpose : A mapping between a "local" ID space and a "global" ID space.
-# License : Copyright (c) 2007, 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2007, 2008, 2009, 2010 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erick.antezana@gmail.com>
+# Contact : Erick Antezana <erick.antezana -@- gmail.com>
 #
 package OBO::Core::IDspace;
 
@@ -34,7 +34,7 @@ A mapping between a "local" ID space and a "global" ID space.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
+Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
